{% extends "nota.html" %}

{% block title %}{% if e %}Solicitud {{ e.id }}{% endif %}{% endblock %}

{% block content %}
{% if e %}
<br />
<div style="float: right; font-size: smaller">
  <em>Expte. <a href="/admin/gea/expediente/{{ e.id }}/">{{ e.id }}</a></em>
</div>
<br />
<div>
  <div>
    <div>Sr. Jefe de la Dirección de Topocartografía</div>
    <div>SERVICIO de CATASTRO e INFORMACIÓN TERRITORIAL</div>
    <div>{{ circunscripcion }}</div>
    <div style="width: 30%"><hr></div>
  </div>
  <p>De nuestra mayor consideración:</p>
  <p class="sangria">{% if e.firmantes_count > 1 %}Quienes suscriben,{% else %}Quien suscribe,{% endif %}
  {% for p in e.propietarios %}
    <a href="/admin/gea/persona/{{ p.persona.id }}/"><strong>
    {% if p.sucesion %}Sucesor{% if e.firmantes_count > 1 %}es{% endif %} de {% endif %}
    {{ p.persona.nombre_completo }}
    {% if p.sucesion %}(*){% endif %}
    {% if p.nuda_propiedad %}(* nuda propiedad){% endif %}</strong></a>,
  {% endfor %}
  patrocinado{% if e.firmantes_count > 1 %}s{% endif %} por
  {% for profesional in e.profesionales_firmantes.all %}
    {{ profesional.titulo }} {{ profesional.nombres }} {{ profesional.apellidos }},
    ICoPA {{ profesional.icopa }},
  {% endfor %}
  SOLICITA{% if e.firmantes_count > 1 %}N{% endif %} la inscripción del Plano
  {% for objeto in e.objetos.all %}
    de <a href="/admin/gea/objeto/{{ objeto.id }}/"><strong>{{ objeto.nombre.upper }}</strong></a>,
  {% endfor %}
  que se acompaña.</p>
  <p class="sangria">Se adjunta documentación que complementa al expediente digital.</p>
  <p class="sangria">{% if e.expedientepartida_set.count > 1 %}Los inmuebles mensurados están ubicados en{% else %}El inmueble mensurado está ubicado en{% endif %}
  {% for ep in e.expedientelugar_set.all %}
    {% if forloop.last and e.expedientelugar_set.count > 1 %}
    y
    {% elif not forloop.first %},
    {% endif %}
    <a href="/admin/gea/lugar/{{ ep.lugar.id }}/"><strong>{{ ep.lugar.nombre }}</strong></a>{% if forloop.last %}:{% endif %}
  {% endfor %}
  {% if e.expedientepartida_set %}
    <ul>
    {% for ep in e.expedientepartida_set.all %}
      {% with ep.partida as p %}<li>
      Distrito <a href="/admin/gea/ds/{{ p.sd.ds.id }}/"><strong>{{ p.sd.ds.nombre }}</strong></a>,
      Depto. <a href="/admin/gea/dp/{{ p.sd.ds.dp }}/"><strong>{{ p.sd.ds.dp.nombre|upper }}</strong></a>,
      Partida de Impuesto Inmobiliario
      <a href="/admin/gea/partida/{{ p.id }}/"><strong>{{ p.partida_completa }}-</strong></a>,
      {% endwith %}
      {% for c in ep.catastro_set.all %}
        {% if c.zona %}Zona <strong>{% if c.zona.id == 1 %}U{% elif c.zona.id > 3 %}R{% else %}S{% endif %}</strong>,{% endif %}
        {% if c.seccion %}Sección <strong>{{ c.seccion }}</strong>, {% endif %}
        {% if c.poligono %}Polígono <strong>{{ c.poligono }}</strong>, {% endif %}
        {% if c.manzana %}Manzana <strong>{{ c.manzana }}</strong>, {% endif %}
        {% if c.parcela %}Parcela <strong>{{ c.parcela }}</strong>, {% endif %}
        Subparcela {% if c.subparcela %}<strong>{{ c.subparcela }}</strong>{% else %}-- {% endif %}.
      {% endfor %}
      </li>
    {% endfor %}
    </ul>
  {% endif %}
  <p class="sangria">
    {% if e.firmantes_count > 1 %}
    Las personas antes nombradas firman
    {% else %}
    La persona antes nombrada firma
    {% endif %}
    al pie de la presente, fijando su DOMICILIO FISCAL en <strong>{{ domfiscal.upper }}</strong>
    de la localidad de <strong>{{ localidad }}</strong>, Código Postal <strong>{{ cp }}</strong>,
    {% ifnotequal provincia 'CAPITAL FEDERAL' %}
    Provincia de <strong>{{ provincia }}</strong>
    {% else %}
    <strong>{{ provincia }}</strong>
    {% endifnotequal %}.
  </p>
  <p class="sangria">Saludamos muy atentamente.</p>
  <br /><br />
  <table>
    <tr>
      <th style="width: 30%">Firma</th>
      <th>Nombre</th>
      <th>Tipo y Nº Doc.</th>
      <th>CUIT/CUIL/CDI</th>
    </tr>
    {% for p in e.firmantes %}
      <tr style="height: 80px">
        <td></td>
        <td>{{ p.persona.apellidos }}<br>{{ p.persona.nombres }}<br>{% if p.partes_indivisas_propias %}<small>({{ p.partes_indivisas_propias }}/{{ p.partes_indivisas_total }} partes indivisas)</small>{% endif %}</td>
        <td>{% if p.persona.documento %}{% if p.persona.show_tipo_doc %}{{ p.persona.show_tipo_doc }}: {% endif %}{{ p.persona.documento }}{% endif %}</td>
        <td style="text-align: right">{{ p.persona.cuit_cuil }}</td>
      </tr>
    {% endfor %}
  </table>
  {% if nota %}<p><strong>(*) {{ nota_titulo }}:</strong></p><p>{{ nota }}</p>{% endif %}
</div>    
{% else %}
  <p>No existe el expediente.</p>
{% endif %}
{% endblock %}
