{% extends "nota.html" %}

{% block title %}{% if e %}Visaci&oacute;n {{ e.id }}{% endif %}{% endblock %}


{% block content %}
{% if e %}
  <br>
  <div style="float: right; font-size: smaller">
    <em>Expte. <a href="/admin/gea/expediente/{{ e.id }}/">{{ e.id }}</a></em>
  </div>
  {% if e.expedientelugar_set.all %}
    {% for el in e.expedientelugar_set.all %}
        <br><br><br>
        <div style="text-align: right">Gálvez, {% now 'j \d\e F, Y' %}</div>
        <div>
          <div>
            <div>{{ sr }}</div>
            <div>{{ localidad }}</div>
            <div><u>S&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;/&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;D</u></div>
          </div>
          <p>De mi mayor consideración:</p>
          <p class="sangria">Quien suscribe,
          {% for profesional in e.profesionales_firmantes.all %}
            <strong>
              {{ profesional.titulo }}
              {{ profesional.nombres }}
              {{ profesional.apellidos }}</strong>, 
          {% endfor %}
          SOLICITA la visación del Plano de
          {% for objeto in e.objetos.all %}
            <strong>{{ objeto.nombre.upper }}</strong>, 
          {% endfor %}
          de la propiedad de
          {% for p in e.propietarios %}
            <strong>
            {% if p.sucesion %}Sucesor{% if e.firmantes_count > 1 %}es{% endif %} de {% endif %}
            {{ p.persona.nombre_completo }}</strong>,
          {% endfor %}
          ubicada en su distrito: {{ e.expedientepartida_set.first.partida.sd.ds.nombre|upper }}, {{ el.lugar.nombre }}
          {% if el.catastrolocal_set.all %}
            (
            {% for c in el.catastrolocal_set.all %}
              {{ c }}{% if c.subparcela %} - Subparcela:{{c.subparcela}}{% endif %}{% if c.suburbana %}, Zona Suburbana{% endif %}{% if not forloop.last %}; {% endif %}
            {% endfor %}
            )
          {% endif %}.</p>
          <p class="sangria">Se adjuntan dos copias del plano.</p>
          <p class="sangria">Sin más, saludo a UD. muy atte.</p>
        </div>
        <br><br><br><br><br>
        <div style="text-align: right;">
          {% for profesional in e.profesionales_firmantes.all %}
          <span style="text-decoration: overline">
            {{ profesional.nombres }} {{ profesional.apellidos }}
          </span><br>
          {{ profesional.titulo }}<br>
          ICoPA Nº {{ profesional.icopa }}<br>
          CUIT: {{ profesional.cuit_cuil }}
          {% endfor %}
        </div>

    {% endfor %}
  {% endif %}
{% endif %}
{% endblock %}
