# Generated by Django 3.0.6 on 2020-05-06 21:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0002_auto_20200505_1940'),
    ]

    operations = [
        migrations.AlterField(
            model_name='persona',
            name='documento',
            field=models.IntegerField(blank=True, default=None, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='persona',
            name='lugar',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Lugar'),
        ),
        migrations.AlterField(
            model_name='persona',
            name='tipo_doc',
            field=models.SmallIntegerField(blank=True, choices=[(0, 'DNI'), (1, 'LC'), (2, 'LE'), (3, 'Otro')], default=None, null=True),
        ),
    ]
