<nav class="navbar navbar-expand-lg navbar-dark" style="background-color: black;">
  <button class="navbar-toggler navbar-toggler-right" type="button" data-toggle="collapse" data-target="#navbarToggler"
    aria-controls="navbarToggler" aria-expanded="false" aria-label="Toggle navigation">
    <span class="navbar-toggler-icon"></span>
  </button>
  <a class="navbar-brand mb-0 h1" href="{% url 'home' %}">
    <i class="far fa-folder-open mr-2"></i> GEA
  </a>
  <div class="collapse navbar-collapse" id="navbarToggler">
    <ul class="navbar-nav mr-auto mt-2 mt-md-0">
      <!-- Listados -->
      <li class="nav-item dropdown">
        <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown"
          aria-haspopup="true" aria-expanded="false">
          <i class="fas fa-list"></i> Listados
        </a>
        <div class="dropdown-menu" aria-labelledby="navbarDropdown">
          <a class="dropdown-item" href="{% url 'expedientes' %}"><i class="far fa-folder"></i> Expedientes</a>
          <a class="dropdown-item" href="{% url 'personas' %}"><i class="fas fa-users"></i> Personas</a>
          <div class="dropdown-divider"></div>
          <a class="dropdown-item" href="{% url 'catastros_locales' %}"><i class="fas fa-map-signs"></i> Catatros
            Locales</a>
        </div>
      </li>
      <!-- Notas -->
      <li class="nav-item dropdown">
        <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown"
          aria-haspopup="true" aria-expanded="false">
          <i class="fas fa-paperclip"></i> Notas
        </a>
        <div class="dropdown-menu" aria-labelledby="navbarDropdown">
          <a class="dropdown-item" href="{% url 'solicitud' %}"><i class="far fa-sticky-note"></i> Solicitud de
            Inscripcion SCIT</a>
          <a class="dropdown-item" href="{% url 'visacion' %}"><i class="far fa-sticky-note"></i> Visación
            Comunal/Municipal</a>
        </div>
      </li>
      <!-- Buscar -->
      <li class="nav-item dropdown">
        <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown"
          aria-haspopup="true" aria-expanded="false">
          <i class="fas fa-search"></i> Buscar
        </a>
        <div class="dropdown-menu" aria-labelledby="navbarDropdown">
          <a class="dropdown-item" href="{% url 'buscar_plano' %}"><i class="far fa-map"></i> Nº de Plano</a>
          <a class="dropdown-item" href="{% url 'buscar_set' %}"><i class="far fa-sticky-note"></i> Informe
            Catastral</a>
          <a class="dropdown-item" href="{% url 'buscar_catastro' %}"><i class="fas fa-map-signs"></i> Catastros
            locales</a>
        </div>
      </li>
      <!-- Herramientas -->
      <li class="nav-item dropdown">
        <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown"
          aria-haspopup="true" aria-expanded="false">
          <i class="fas fa-wrench"></i> Herramientas
        </a>
        <div class="dropdown-menu" aria-labelledby="navbarDropdown">
          <a class="dropdown-item" href="{% url 'caratula' %}"><i class="far fa-map"></i> Carátula Sencilla de Plano de
            Mensura</a>
          <a class="dropdown-item" href="{% url 'dvapi' %}"><i class="fas fa-calculator"></i> Dígito Verificador API</a>
          <a class="dropdown-item" href="{% url 'sie' %}"><i class="far fa-folder"></i> Sistema de Información de
            Expedientes del SCIT</a>
        </div>
      </li>
      <!-- Acerca de -->
      <li class="nav-item">
        <a class="nav-link" href="{% url 'about' %}"><i class="fas fa-info mr-2"></i> Acerca de</a>
      </li>
    </ul>
    <ul class="navbar-nav ml-md-auto">
      {% if user.is_staff %}
      <!-- admin -->
      <li class="nav-item">
        <a class="nav-link" href="{% url 'admin:index' %}"><i class="fas fa-user-shield"></i> admin</a>
      </li>
      {% endif %}
      {% if user.is_authenticated %}
      <!-- profile -->
      <li class="nav-item">
        <a class="nav-link" href="#">
          <i class="fas fa-user"></i>
          {% if user.first_name %}{{ user.first_name }}{% else %}{{ user.username }}{% endif %}
        </a>
      </li>
      <!-- logout -->
      <li class="nav-item">
        <a class="nav-link" href="{% url 'logout' %}"><i class="fas fa-sign-out-alt"></i> Salir</a>
      </li>
      {% endif %}
    </ul>
  </div>
</nav>