# Generated by Django 3.0.6 on 2020-05-05 22:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profesional',
            name='cuit_cuil',
            field=models.CharField(blank=True, max_length=14, verbose_name='CUIT/CUIL'),
        ),
    ]
