# Generated by Django 3.0.6 on 2020-05-20 20:24

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('gea', '0004_auto_20200513_1915'),
    ]

    operations = [
        migrations.AlterField(
            model_name='partida',
            name='sd',
            field=models.ForeignKey(blank=True, db_column='sd', default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='gea.Sd'),
        ),
        migrations.AlterField(
            model_name='partida',
            name='subpii',
            field=models.IntegerField(blank=True),
        ),
    ]
