{% extends 'base.html' %}
{% load i18n %}

{% block title %}GEA | Login{% endblock %}

{% block content %}
<h2><i class="fas fa-fw fa-sign-in-alt"></i> <strong>GEA</strong> {% trans "Ingreso" %}</h2>
<form class="form-horizontal col-md-offset-4 col-md-4" method="post">{% csrf_token %}
  <fieldset>
    <div class="form-group">
      <table class="table table-condensed table-hover">
        {{ form.as_table }}
      </table>
      <button type="submit" class="btn btn-primary pull-right">
        <i class="fas fa-fw fa-sign-in-alt"></i>
        {% trans "Ingresar" %}
      </button>
    </div>
  </fieldset>
</form>
{% endblock %}
{% block top %}{% endblock %}