{% extends 'base.html' %}

{% block title %}GEA | Logout{% endblock %}

{% block content %}
<h2><i class="fas fa-fw fa-sign-out-alt"></i> <strong>GEA</strong> Sesión cerrada</h2>
<br>
<div class="text-center" method="post">{% csrf_token %}
    <a href="{% url 'login'%}" class="btn btn-primary">Ingresar nuevamente</a></p>
</div>
{% endblock %}
{% block top %}{% endblock %}
