<!DOCTYPE html>
<html lang="es">

<head>
  {% load static %}
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta name="description" content="Gesti&oacute;n de Expedientes de Agrimensores">
  <meta name="author" content="GEAdevel">
  <link rel="shortcut icon" href="{% static 'img/folder-o.png' %}">
  <title>{% block title %}GEA{% endblock title %}</title>
  <!-- Bootstrap core CSS -->
  <link href="{% static 'css/bootstrap.min.css' %}" rel="stylesheet">
  <script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.13.0/js/all.min.js"
    integrity="sha256-KzZiKy0DWYsnwMF+X1DvQngQ2/FxF7MF3Ff72XcpuPs=" crossorigin="anonymous"></script>
  {% block css %}
  {% endblock css %}
  <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
  <!--[if lt IE 9]>
      <script src="/static/js/html5shiv.js"></script>
      <script src="/static/js/respond.min.js"></script>
    <![endif]-->
  {% block js %}
  {% endblock js %}
</head>
<!-- <body ng-app="base"> -->

<body>
  <!-- MENU -->
  {% block menu %}{% include "menu.html" %}{% endblock menu %}
  {% block float %}{% endblock float %}
  <div class="container">
    {% block content %}
    {% endblock content %}
  </div> <!-- /container -->
  {% block footer %}
  <!-- FOOTER -->
  <footer>
    <div class="container">
      <div class="row clearfix">
        <div class="col-md-12 column">
          <hr>
          {% block top %}
          <a href="#" class="pull-right"><i class="fas fa-fw fa-chevron-up"></i> Arriba</a>
          {% endblock top %}
          <p class="text-center"><strong>GEA</strong> &copy; {% now "Y" %} &mdash; Todos los derechos reservados.</p>
        </div>
      </div>
    </div><!-- footer-container -->
  </footer>
  {% endblock footer %}
  <!-- Bootstrap core JavaScript -->
  <!-- Placed at the end of the document so the pages load faster -->
  <script src="//code.jquery.com/jquery-1.11.3.min.js"></script>
  <script src="{% static 'js/bootstrap.min.js' %}"></script>
</body>

</html>