{% extends "base.html" %}
{% block title %}GEA | Expediente {{ object.id }}{% endblock title %}

{% block float %}
<div class="well" style="position: fixed; margin: 0em 0em; transform-origin: 50% 65%; transform: rotate(-90deg);">
    <h3>
        <i class="fas fa-fw fa-folder"></i>
        N&ordm; <strong>{{ expediente.id }}</strong>
    </h3>
</div>
{% endblock float %}

{% block content %}
{% load static %}

<div class="col-lg-8">
    <div class="column">
        <!-- Expediente -->
        <h1><i class="fas fa-fw fa-folder"></i> Expediente N&ordm; {{ object.id }}</h1>
        <!-- Comitentes -->
        {% if object.comitentes_count %}
        <h2><i class="fas fa-fw fa-file-signature"></i> Comitente{% if object.comitentes_count > 1%}s{% endif %}:
        {% for p in object.comitentes %}
            <a href="{% url 'persona' p.persona.id %}">{{ p.persona.nombre_completo }}</a>{% if not forloop.last %},{% endif %}
        {% endfor %}
        </h2>
        {% endif %}
        <!-- Propietarios -->
        {% if object.propietarios_count %}
        <h3>{% if object.propietarios_count > 1 %}<i class="fas fa-fw fa-users"></i> Propietarios:{% else %}<i class="fas fa-fw fa-user"></i> Propietario:{% endif %}
        {% for p in object.propietarios %}
            <a href="{% url 'persona' p.persona.id %}">{{ p.persona.nombre_completo }}</a>{% if not forloop.last %},{% endif %}
        {% endfor %}
        </h3>
        {% endif %}
        <h3>{{ object.expedientelugar_set.first }}</h3>
    </div>
    </br>
    <table class="table table-user-information">
        <tbody>
            <tr>
                <th class="col-md-3 text-right">Alta</th>
                <td>{{ object.created }}</td>
            </tr>
            <tr>
                <th class="col-md-3 text-right">Lugar</th>
                <td>{{ object.expedientelugar_set.first }}</td>
            </tr>
            <tr>
                <th class="col-md-3 text-right">Fecha</th>
                <td>{{ object.inscripcion_fecha }}</td>
            </tr>
            <tr>
                <th class="col-md-3 text-right">Plano</th>
                <td><a href="{{ object.plano_ruta }}">{{ object.inscripcion_numero }}</a></td>
            </tr>
        </tbody>
    </table>
</div>
<div class="col-md-2 column">
    <img src="{% static 'img/globe.png' %}" class="img-square" />
</div>

{% endblock content %}