<!doctype html>
<html lang="es">

<head>
  {% load static %}
  <!-- Required meta tags -->
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

  <!-- Bootstrap CSS // Hackerthemes -->
  <link href="{% static 'css/bootstrap.min.css' %}" rel="stylesheet">
  {% block extra_css %}{% endblock extra_css %}

  <!-- Fontawesome CDN -->
  <script src="https://kit.fontawesome.com/7af3127492.js" crossorigin="anonymous"></script>

  <!-- Description & Author -->
  <meta name="description" content="Gesti&oacute;n de Expedientes de Agrimensores">
  <meta name="author" content="GEAdevel">

  <!-- Icon -->
  <link rel="shortcut icon" href="{% static 'img/folder-o.png' %}">

  <title>{% block title %}GEA{% endblock title %}</title>
</head>

<body id="page-top">
  {% include "topbar.html" %}
  <div class="container-fluid">
    {% block content %}
    <h1>Hello, world!</h1>
    {% endblock content %}
  </div>

  {% block footer %}
  <!-- Footer -->
  <footer id="footer">
    <!-- Copyright -->
    <div class="text-center p-3">
      <strong><span>GEA</span></strong> &copy; {% now "Y" %}. Todos los derechos reservados.
      <a class="text-dark" href="#">GEAdevel</a>
    </div>
    <!-- Copyright -->
  </footer>
  <!-- Footer -->
  {% endblock footer %}

  <!-- Scroll to Top Button-->
  <a class="btn btn-sm btn-primary d-print-none mr-auto" href="#page-top" style="display: inline;">
    <i class="fas fa-angle-up"></i>
  </a>

  <!-- jQuery and Bootstrap Bundle (includes Popper) -->
  <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"
    integrity="sha384-DfXdz2htPH0lsSSs5nCTpuj/zy4C+OGpamoFVy38MVBnE+IbbVYUew+OrCXaRkfj"
    crossorigin="anonymous"></script>
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"
    integrity="sha384-Piv4xVNRyMGpqkS2by6br4gNJ7DXjqk09RmUpJ8jgGtD7zP9yug3goQfGII0yAns"
    crossorigin="anonymous"></script>
  {% block extra_js %}{% endblock extra_js %}
</body>

</html>