{% extends "base.html" %}
{% block title %}GEA | Catastos Locales{% endblock title %}

{% block content %}
{% load tags %}
<div class="page-header">
  <h1>
    <i class="fas fa-fw fa-map-signs"></i> <a href="{% url 'catastros_locales' %}">Catastros Locales</a>
    {% if lugar %}<font size=4>{{ lugar }}
    - sección:<strong>{{ seccion|default:"todas" }}</strong>
    - manzana:<strong>{{ manzana|default:"todas" }}</strong>
    - parcela:<strong>{{ parcela|default:"todas" }}</strong>
    </font>{% endif %}
  </h1>
  <strong>{{ count }}</strong> expediente{% if count > 1 %}s{% endif %} filtrado{% if count > 1 %}s{% endif %}
</div>

<!-- Lugares -->
<div class="well well-sm">
  <div class="row">
    <div class="col-lg-1">Lugares</div>
    <div class="dropdown col-lg-4">
      <button class="btn btn-sm btn-default dropdown-toggle" type="button" id="lugar" name="lugar" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
        Lugar
        <span class="caret"></span>
      </button>
      <ul class="dropdown-menu">
        {% for l in lugares %}
        <li class="{% if lugar == l %}active{% endif %}"><a href="{% url 'catastros_locales' %}?lugar={{ l }}">{{ l }}</a></li>
        {% endfor %}
      </ul>
      <strong>{{ lugar|default:"" }}</strong>
    </div>
    <div class="col-lg-1">Secciones</div>
    <div class="col-lg-6 btn-group btn-group-sm" role="group">
      <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}" class="btn {% if not seccion %} btn-default active{% else %} btn-info{% endif %}">*</a>
      {% for s in secciones %}
      <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}&seccion={{ s }}" class="btn{% if seccion == s %} btn-default active{% else %} btn-primary{% endif %}">{{ s }}</a>
      {% endfor %}
    </div>
  </div>
  <div class="row">
    <div class="col-lg-1">Manzanas</div>
    <div class="col-lg-11 btn-group btn-group-sm" role="group">
      <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}" class="btn{% if not manzana %} btn-default active{% else %} btn-info{% endif %}">*</a>
      {% for m in manzanas %}
      <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}{% if seccion %}&seccion={{ seccion }}{% endif %}&manzana={{ m }}" class="btn{% if manzana == m %} btn-default active{% else %} btn-primary{% endif %}">{{ m }}</a>
      {% endfor %}
    </div>
    <div class="col-lg-1">Parcelas</div>
    <div class="col-lg-11 btn-group btn-group-sm" role="group">
      <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}&seccion={{ seccion }}&manzana={{ manzana }}" class="btn {% if not parcela %} btn-default active{% else %} btn-info{% endif %}">*</a>
      {% for p in parcelas %}
      <a href="{% url 'catastros_locales' %}?lugar={{ lugar }}&seccion={{ seccion }}&manzana={{ manzana }}&parcela={{ p }}" class="btn{% if parcela == p %} btn-default active{% else %} btn-primary{% endif %}">{{ p }}</a>
      {% endfor %}
    </div>
  </div>
</div>

{% include "_pagination.html" %}
<table class="table table-bordered table-condensed table-hover">
  <thead>
    <tr>
      <th>Expediente</th>
      <th>Persona(s)</th>
      <th>Lugar(es)</th>
      <th>Partida(s)</th>
      <th>Plano</th>
    </tr>
  </thead>
  <tbody>
    {% for e in object_list %}
    <tr>
      <td><!-- EXPEDIENTE -->
        <a href="/admin/gea/expediente/{{ e.id }}/">{{ e.id }}</a>
        <!--<a href="{% url 'expediente' e.id %}">{{ e.id }}</a>-->
      </td>
      <td><!-- PERSONAS -->
      {% if e.orden_numero and not e.inscripcion_numero %}<span class="label label-warning">PENDIENTE</span> Orden N&ordm; {{ e.orden_numero }} - {{ e.orden_fecha }}<br>{% endif %}
      {% if e.cancelado %}<span class="label label-danger">CANCELADO</span> {{ e.cancelado_por }}<br>{% endif %}
      {% if e.expedientepersona_set %}
        {% for ep in e.expedientepersona_set.all %}
        <a href="/admin/gea/persona/{{ ep.persona.id }}/">{{ ep.persona.nombre_completo }}</a>
          {% if ep.comitente %}<span class="label label-primary">COMITENTE</span>{% endif %}
          {% if ep.persona.telefono %}({{ ep.persona.telefono }}){% endif %}
          {% if ep.persona.celular %}({{ ep.persona.celular }}){% endif %}
          {% if not forloop.last %}<br>{% endif %}
        {% endfor %}
      {% endif %}
      </td>
      <td><!-- LUGARES -->
      {% if e.expedientelugar_set %}
        {% for el in e.expedientelugar_set.all %}
        <a href="/admin/gea/lugar/{{ el.lugar.id }}/">{{ el.lugar.nombre }}</a> {% for cl in el.catastrolocal_set.all %}<br>{{ cl }}{% endfor %}{% if not forloop.last %}<br>{% endif %}
        {% endfor %}
      {% endif %}
      </td>
      <td><!-- PARTIDAS -->
      {% if e.expedientepartida_set %}
        {% for ep in e.expedientepartida_set.all %}
          {% if ep.set_ruta %}<a href="{{ ep.set_ruta }}">{% endif %}{{ ep.partida.sd }}-{{ ep.partida }}{% if ep.set_ruta %}</a>{% endif %}{% if not forloop.last %}<br>{% endif %}
        {% endfor %}
      {% endif %}
      </td>
      <td><!-- PLANO -->
        {% if e.plano_ruta %}<a href="{{ e.plano_ruta }}">{% endif %}{% if e.duplicado %}Dup.{% endif %}{% if e.inscripcion_numero %}{{ e.inscripcion_numero }}{% endif %}{% if e.plano_ruta %}</a>{% endif %}
        {% if e.inscripcion_fecha %}({{ e.inscripcion_fecha }}){% endif %}
        {% if e.sin_inscripcion %}<span class="label label-info">NO REQUIERE</span>{% endif %}
      </td>
    </tr>
    {% empty %}
    <div class="alert alert-info" role="alert">
      <i class="fas fa-fw fa-info-circle" aria-hidden="true"></i>
      <span class="sr-only">Información:</span>
      No se encontraron Expedientes.
    </div>
    {% endfor %}
  </tbody>
</table>
{% include "_pagination.html" %}
{% endblock content %}
